@@ -61,7 +61,7 @@
 #define DEFAULT_KEY_DROP		KSYM_Control_R
 #endif
 #define DEFAULT_KEY_OKAY		KSYM_Return
-#define DEFAULT_KEY_CANCEL		KSYM_Escape
+#define DEFAULT_KEY_CANCEL		KSYM_BackSpace
 
 /* default shortcut keys */
 #define DEFAULT_KEY_SAVE_GAME		KSYM_F1
